summaryrefslogtreecommitdiff
path: root/tests/tui_pow.c
diff options
context:
space:
mode:
authorzimmerma <zimmerma@280ebfd0-de03-0410-8827-d642c229c3f4>2004-02-14 23:05:51 +0000
committerzimmerma <zimmerma@280ebfd0-de03-0410-8827-d642c229c3f4>2004-02-14 23:05:51 +0000
commit6e5ffc68a8061e42a2680dd99455f89e2f4f8ca9 (patch)
tree3150eedf9dc6ae8d160042147ff46ac533e723dd /tests/tui_pow.c
parentf095a6c8a44a63379841097ddfbf4682e56e4036 (diff)
downloadmpfr-6e5ffc68a8061e42a2680dd99455f89e2f4f8ca9.tar.gz
new coverage tests
git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@2714 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'tests/tui_pow.c')
-rw-r--r--tests/tui_pow.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/tests/tui_pow.c b/tests/tui_pow.c
index 4da7010cf..99aebef56 100644
--- a/tests/tui_pow.c
+++ b/tests/tui_pow.c
@@ -1,6 +1,6 @@
-/* Test file for mpfr_ui_pow.
+/* Test file for mpfr_ui_pow and mpfr_ui_pow_ui.
-Copyright 2001, 2002, 2003 Free Software Foundation.
+Copyright 2001, 2002, 2003, 2004 Free Software Foundation.
Adapted from tarctan.c.
This file is part of the MPFR Library.
@@ -49,6 +49,9 @@ test1 (void)
exit (1);
}
+ mpfr_ui_pow_ui (x, 0, 1, GMP_RNDN);
+ MPFR_ASSERTN(mpfr_cmp_ui (x, 0) == 0 && MPFR_IS_POS (x));
+
mpfr_clear (x);
mpfr_clear (y);
}